//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	exit;
}

class indisposable_hook_C_CoreFrontSystemRegister extends _HOOK_CLASS_
{
    /**
     * Member is using a disposable e-mail. Bad member. Change that.
     *
     * @return	void
     */
    protected function disposableEmailSplash()
    {
	try
	{
	        if( !\IPS\Member::loggedIn()->member_id )
	        {
	            \IPS\Output::i()->redirect( \IPS\Http\Url::internal( '' ) );
	        }
	
        // Make sure we're actually using a disposable e-mail and forced e-mail changes are enabled
	        try
	        {
	            $disposable = \IPS\Db::i()->select( '*', 'indisposable_members', array( 'member_id=?', \IPS\Member::loggedIn()->member_id ) )->first();
	        }
	        catch ( \UnderflowException $e )
	        {
	            \IPS\Output::i()->error( 'indisposable_no_record', '2ID100/1', 404, '' );
	        }
	
        // Are we forcing them to change their e-mail?
	        if ( \IPS\Settings::i()->indisposable_member_action === 'force' )
	        {
	            \IPS\Output::i()->title	= \IPS\Member::loggedIn()->language()->addToStack('indisposable_change_email');
	            \IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'email', 'indisposable' )->forceChange();
	            return;
	        }
	
        // Or just prompting them to on login?
		    $ref = \IPS\Request::i()->cookie['indisposableRef'] ?? (string)\IPS\Http\Url::internal( '' );
	        \IPS\Request::i()->setCookie( 'indisposableRef', NULL );
	
	        \IPS\Output::i()->title	= \IPS\Member::loggedIn()->language()->addToStack('indisposable_change_email');
	        \IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'email', 'indisposable' )->promptChange( $ref );
	}
	catch ( \RuntimeException $e )
	{
		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

    /**
     * Change Email
     *
     * @return	void
     */
    protected function changeDisposableEmail()
    {
	try
	{
        // Are we logged in and using a disposable e-mail?
	        if( !\IPS\Member::loggedIn()->member_id or !\IPS\Member::loggedIn()->isDisposable() )
	        {
	            \IPS\Output::i()->error( 'no_module_permission', '2ID101/1', 403, '' );
	        }
	
        // Build the e-mail change form
	        $form = new \IPS\Helpers\Form;
	        $form->class = 'ipsForm_vertical';
	        $form->add( new \IPS\Helpers\Form\Email( 'new_email', '', TRUE, array( 'accountEmail' => \IPS\Member::loggedIn() ) ) );
	        $captcha = new \IPS\Helpers\Form\Captcha;
	        if ( (string) $captcha !== '' )
	        {
	            $form->add( $captcha );
	        }
	
	        if ( $values = $form->values() )
	        {
	            $oldEmail = \IPS\Member::loggedIn()->email;
	            \IPS\Member::loggedIn()->email = $values['new_email'];
	            \IPS\Member::loggedIn()->save();
	
	            foreach ( \IPS\Login::methods() as $method )
	            {
	                try
	                {
	                    $method->changeEmail( \IPS\Member::loggedIn(), $oldEmail, $values['new_email'] );
	                }
	                catch( \BadMethodCallException $e ) {}
	            }
	
	            \IPS\Member::loggedIn()->memberSync( 'onEmailChange', array( $values['new_email'], $oldEmail ) );
	            \IPS\Member::loggedIn()->logHistory( 'core', 'email_change', array( 'old' => $oldEmail, 'new' => $values['new_email'], 'by' => 'manual' ) );
	
            // Invalidate sessions except this one
	            \IPS\Member::loggedIn()->invalidateSessionsAndLogins( \IPS\Session::i()->id );
	            if( isset( \IPS\Request::i()->cookie['login_key'] ) )
	            {
	                \IPS\Member\Device::loadOrCreate( \IPS\Member::loggedIn() )->updateAfterAuthentication( TRUE );
	            }
	
            // Do we need to validate the new e-mail?
	            if ( \IPS\Settings::i()->reg_auth_type === 'user' )
	            {
	                $vid = \IPS\Login::generateRandomString();
	
	                \IPS\Db::i()->insert( 'core_validating', array(
	                    'vid'			=> $vid,
	                    'member_id'		=> \IPS\Member::loggedIn()->member_id,
	                    'entry_date'	=> time(),
	                    'email_chg'		=> TRUE,
	                    'ip_address'	=> \IPS\Request::i()->ipAddress(),
	                    'prev_email'	=> $oldEmail,
	                    'email_sent'	=> time(),
	                ) );
	
	                \IPS\Member::loggedIn()->members_bitoptions['validating'] = TRUE;
	                \IPS\Member::loggedIn()->save();
	
	                \IPS\Email::buildFromTemplate( 'core', 'email_change', array( \IPS\Member::loggedIn(), $vid ), \IPS\Email::TYPE_TRANSACTIONAL )->send( \IPS\Member::loggedIn() );
	            }
	
            // Redirect
	            \IPS\Output::i()->redirect( \IPS\Http\Url::internal( '' ) );
	        }
	
	        \IPS\Output::i()->output = $form->customTemplate( array( \IPS\Theme::i()->getTemplate( 'forms', 'core' ), 'popupTemplate' ) );
	}
	catch ( \RuntimeException $e )
	{
		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }
}
