//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
    exit;
}

class indisposable_hook_C_HelpersFormEmail extends _HOOK_CLASS_
{
    /**
     * Validate (IPS 4.4)
     *
     * @param	string				$value			The provided value (an email address)
     * @param	bool|\IPS\Member	$accountEmail	If TRUE, additional checks will be performed to ensure provided email address is acceptable for use on a user's account. If an \IPS\Member object, that member will be excluded
     * @throws	\InvalidArgumentException
     * @throws	\DomainException
     * @return	TRUE
     */
    static public function validateEmail( $value, $accountEmail )
    {
	try
	{
	    	$contactForm = ( ( \IPS\Request::i()->app === 'core' ) and ( \IPS\Request::i()->module === 'contact' ) and ( \IPS\Request::i()->controller === 'contact' ) );
	
	        if ( ( $accountEmail or $contactForm ) and !\IPS\Member::loggedIn()->isAdmin() )
	        {
	            if ( ( \IPS\Settings::i()->indisposable_action === 'block' ) and \IPS\indisposable\Validator::i()->isDisposable( $value ) )
	            {
	                \IPS\indisposable\Logger::log( $value, 'registration' );
	                throw new \DomainException( 'form_email_disposable' );
	            }
	
	            if ( \IPS\Settings::i()->indisposable_blockAliases and \IPS\indisposable\Validator::i()->isAlias( $value ) )
	            {
	                throw new \DomainException( 'form_email_alias' );
	            }
	        }
	
	        return parent::validateEmail( $value, $accountEmail );
	}
	catch ( \RuntimeException $e )
	{
		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }
}
