//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	exit;
}

class indisposable_hook_C_Member extends _HOOK_CLASS_
{
    /**
     * Check if this member is using a disposable e-mail (and log it if so)
     *
     * @param   null $event The event to use for logging, e.g. "registration", "email_change", ...
     * @return  bool
     */
    public function isDisposable( $event=NULL )
    {
	try
	{
    	// Already marked disposable?
	        if ( \IPS\Db::i()->select( '*', 'indisposable_members', [ 'member_id=?', $this->member_id ] )->count() )
		    {
		    	return TRUE;
		    }
	
    	// We always check again otherwise, just in-case an e-mail was recorded in the disposable address database later
		    if ( $this->email and \IPS\indisposable\Validator::i()->isDisposable( $this->email, TRUE ) )
		    {
	            if ( $event )
	            {
	                \IPS\indisposable\Logger::log( $this->email, $event, $this );
	            }
	
	            \IPS\Db::i()->insert( 'indisposable_members', [ 'member_id' => $this->member_id ] );
		    	return TRUE;
		    }
	
		    return FALSE;
		}
		catch ( \RuntimeException $e )
		{
			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
}
