<?php


namespace IPS\indisposable\modules\admin\indisposable;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * cache
 */
class _cache extends \IPS\Dispatcher\Controller
{	
	/**
	 * Execute
	 *
	 * @return	void
	 */
	public function execute()
	{
		\IPS\Dispatcher::i()->checkAcpPermission( 'cache_manage' );
		parent::execute();
	}
	
	/**
	 * Manage
	 *
	 * @return	void
	 */
	protected function manage()
	{		
		/* Create the table */
		$table = new \IPS\Helpers\Table\Db( 'indisposable_cache', \IPS\Http\Url::internal( 'app=indisposable&module=indisposable&controller=cache' ) );
        $table->langPrefix = 'indisposable_';

        /* Columns we need */
        $table->include = array( 'host', 'first_use', 'last_use', 'uses' );
        $table->mainColumn = 'host';
        $table->rowClasses = array( 'host' => array( 'ipsTable_wrap' ) );

        /* Default sort options */
        $table->sortBy = $table->sortBy ?: 'uses';
        $table->sortDirection = $table->sortDirection ?: 'desc';

        /* Search */
        $table->quickSearch = 'host';

        $table->parsers = array(
            'host'              => function ( $val, $row )
            {
                return '<a href="' . \IPS\Http\Url::external( 'http://' . htmlentities( $val ) )->makeSafeForAcp() . '" target="_blank" rel="noopener">🔗 </a>' . htmlentities( $val );
            },

            'first_use'         => function( $val, $row )
            {
                return \IPS\DateTime::ts( $val )->localeDate();
            },

            'last_use'          => function( $val, $row )
            {
                return \IPS\DateTime::ts( $val )->localeDate();
            },
        );

        /* Specify the buttons */
        $table->rowButtons = function ( $row ) {

            $return = [];

            $return['search'] = [
                'icon'  => 'search',
                'title' => 'indisposable_members_search',
                'link'  => \IPS\Http\Url::internal(
                    '&app=indisposable&module=indisposable&controller=members&sortby=joined&sortdirection=desc&quicksearch=' .
                    \urlencode( $row['host'] )
                ),
                'id'    => "{$row['host']}-search",
                'data'  => [
                    'bubble' => '',
                ]
            ];

            return $return;
        };

        /* Display */
        \IPS\Output::i()->title     = \IPS\Member::loggedIn()->language()->addToStack('indisposable_cache_header');
		\IPS\Output::i()->output    = \IPS\Theme::i()->getTemplate( 'global', 'core' )->block( 'title', (string) $table );
	}
}