<?php


namespace IPS\indisposable\modules\admin\indisposable;

/* To prevent PHP errors (extending class does not exist) revealing path */

use IPS\Session;

if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
    header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
    exit;
}

/**
 * logs
 */
class _logs extends \IPS\Dispatcher\Controller
{	
    /**
     * Execute
     *
     * @return	void
     */
    public function execute()
    {
        \IPS\Dispatcher::i()->checkAcpPermission( 'logs_manage' );
        parent::execute();
    }

    /**
     * Manage
     *
     * @return	void
     */
    protected function manage()
    {
        // Introduction page providing users with the option to port prefixes over from Advanced Tags & Prefixes
        if ( !\IPS\Settings::i()->indisposable_logs_enabled )
        {
            \IPS\Output::i()->output .= \IPS\Theme::i()->getTemplate( 'logs', 'indisposable' )->logsIntroduction();
            return;
        }

        /* Create the table */
        $table = new \IPS\Helpers\Table\Db( 'indisposable_logs', \IPS\Http\Url::internal( 'app=indisposable&module=indisposable&controller=logs' ) );
        $table->langPrefix = 'indisposable_';

        // Excludes
        $table->include = [ 'email', 'uagent', 'ip', 'type', 'member_id', 'timestamp' ];

        $table->parsers = [
            'ip'            => function( $value, $row )
            {
                if ( \IPS\Member::loggedIn()->hasAcpRestriction( 'core', 'members', 'membertools_ip' ) )
                {
                    return "<a href='" . \IPS\Http\Url::internal( "app=core&module=members&controller=ip&ip={$value}" ) . "'>{$value}</a>";
                }

                return $value;
            },
            'type'          => function( $value, $row )
            {
                return \IPS\Member::loggedIn()->language()->addToStack( "indisposable_logs_type_{$value}" );
            },
            'member_id'     => function( $value, $row )
            {
                $member = \IPS\Member::load( $value );

                if ( $member->member_id )
                {
                    return "<a href='" .
                        \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) .
                        $row['member_id'] . "'>" . htmlentities( $member->name, ENT_DISALLOWED, 'UTF-8', FALSE ) . "</a>";
                }

                return $member->name;
            },
            'timestamp'     => function( $value, $row )
            {
                return \IPS\DateTime::ts( $value )->localeDate();
            },
        ];

        $table->rootButtons = [
            'disable'   => [
                'icon'	=> 'power-off',
                'title'	=> 'indisposable_disable',
                'data'  => [ 'confirm' => '', 'confirmSubMessage' => \IPS\Member::loggedIn()->language()->addToStack('indisposable_logs_disable_confirm') ],
                'link'	=> \IPS\Http\Url::internal( "app=indisposable&module=indisposable&controller=logs&do=disable" )->csrf()
            ],

            'prune'     => [
                'icon'  => 'cogs',
                'title' => 'prunesettings',
                'data'  => [ 'ipsDialog' => '', 'ipsDialog-title' => \IPS\Member::loggedIn()->language()->addToStack('prunesettings') ],
                'link'  => \IPS\Http\Url::internal( "app=indisposable&module=indisposable&controller=logs&do=pruneSettings" )
            ]
        ];

        /* Display */
        \IPS\Output::i()->title     = \IPS\Member::loggedIn()->language()->addToStack( 'indisposable_logs_header' );
        \IPS\Output::i()->output    = \IPS\Theme::i()->getTemplate( 'global', 'core' )->block( 'title', (string) $table );
    }

    /**
     * Quickly enable logging
     */
    protected function enable()
    {
        \IPS\Session::i()->csrfCheck();
        \IPS\indisposable\Logger::enable();
        $backUrl = \IPS\Http\Url::internal( 'app=indisposable&module=indisposable&controller=logs' );
        \IPS\Output::i()->redirect( $backUrl );
    }

    /**
     * Quickly disable logging
     */
    protected function disable()
    {
        \IPS\Session::i()->csrfCheck();
        \IPS\indisposable\Logger::disable();
        \IPS\indisposable\Logger::prune();
        $backUrl = \IPS\Http\Url::internal( 'app=indisposable&module=indisposable&controller=logs' );
        \IPS\Output::i()->redirect( $backUrl );
    }

    /**
     * Error log Prune Settings
     *
     * @return	void
     */
    protected function pruneSettings()
    {
        \IPS\Dispatcher::i()->checkAcpPermission( 'logs_manage' );

        $form = new \IPS\Helpers\Form;

        // IPS 4.3 backwards compatibility
        if ( \class_exists( '\IPS\Helpers\Form\Interval' ) )
        {
            $form->add(
                new \IPS\Helpers\Form\Interval(
                    'indisposable_logs_prune', \IPS\Settings::i()->indisposable_logs_prune, FALSE,
                    [ 'valueAs' => \IPS\Helpers\Form\Interval::DAYS, 'unlimited' => 0, 'unlimitedLang' => 'never' ],
                    NULL, \IPS\Member::loggedIn()->language()->addToStack( 'after' ), NULL, 'indisposable_logs_prune'
                )
            );
        }
        else
        {
            $form->add(
                new \IPS\Helpers\Form\Number(
                    'indisposable_logs_prune', \IPS\Settings::i()->indisposable_logs_prune, FALSE,
                    [ 'unlimited' => 0, 'unlimitedLang' => 'never' ], NULL, \IPS\Member::loggedIn()->language()->addToStack( 'after' ),
                    \IPS\Member::loggedIn()->language()->addToStack( 'days' ), 'indisposable_logs_prune'
                )
            );
        }

        if ( $values = $form->values() )
        {
            $form->saveAsSettings();
            \IPS\Output::i()->redirect( \IPS\Http\Url::internal( 'app=indisposable&module=indisposable&controller=logs' ), 'saved' );
        }

        \IPS\Output::i()->title	    = \IPS\Member::loggedIn()->language()->addToStack('indisposable_logs_prune');
        \IPS\Output::i()->output    = (string)$form;
    }
}