<?php


namespace IPS\indisposable\modules\admin\indisposable;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
    header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
    exit;
}

/**
 * members
 */
class _members extends \IPS\Dispatcher\Controller
{
    /**
     * Execute
     *
     * @return    void
     */
    public function execute()
    {
        \IPS\Dispatcher::i()->checkAcpPermission( 'members_manage' );
        parent::execute();
    }

    /**
     * Manage
     *
     * @return    void
     * @noinspection DuplicatedCode
     */
    protected function manage()
    {
        /* Create the table */
        $table = new \IPS\Helpers\Table\Db(
            'indisposable_members', \IPS\Http\Url::internal( 'app=indisposable&module=indisposable&controller=members' )
        );
        $table->langPrefix = 'members_';
        //$table->where = 'disposable_email=1';

        \IPS\Output::i()->sidebar['actions']['reindex'] = array(
            'primary'	=> true,
            'icon'		=> 'refresh',
            'title'		=> 'indisposable_reindex',
            'link'		=> \IPS\Http\Url::internal( "app=indisposable&module=indisposable&controller=members&do=reindex" )->csrf(),
            'data'		=> array( 'confirm' => '', 'confirmSubMessage' => \IPS\Member::loggedIn()->language()->addToStack('indisposable_reindex_confirm') )
        );

        /* Columns we need */
        $table->include = [ 'photo', 'name', 'email', 'joined', 'group_name', 'ip_address' ];
        $table->mainColumn = 'name';
        $table->noSort = [ 'photo' ];
        $table->rowClasses = [ 'email' => [ 'ipsTable_wrap' ], 'group_name' => [ 'ipsTable_wrap' ] ];

        /* Default sort options */
        $table->sortBy = $table->sortBy ?: 'joined';
        $table->sortDirection = $table->sortDirection ?: 'desc';

        /* Joins */
        $table->joins = array(
            array(
                'select' => 'm.*',
                'from' => array( 'core_members', 'm' ),
                'where' => 'm.member_id=indisposable_members.member_id' )
        );


        /* Search */
        $table->quickSearch = 'email';

        /* Custom parsers */
        $table->parsers = [
            'email'            => function ( $val, $row ) {
                return \IPS\Theme::i()->getTemplate( 'members', 'core', 'admin' )->memberEmailCell(
                    htmlentities( $val, ENT_DISALLOWED, 'UTF-8', FALSE )
                );
            },
            'photo'            => function ( $val, $row ) {
                return \IPS\Theme::i()->getTemplate( 'global', 'core' )->userPhoto(
                    \IPS\Member::constructFromData( $row ), 'tiny'
                );
            },
            'joined'           => function ( $val, $row ) {
                return \IPS\DateTime::ts( $val )->localeDate();
            },
            'group_name'       => function ( $val, $row ) {
                $secondary = \IPS\Member::constructFromData( $row )->groups;

                foreach ( $secondary as $k => $v )
                {
                    if ( $v == $row['member_group_id'] or $v == 0 )
                    {
                        unset( $secondary[ $k ] );
                        continue;
                    }

                    $secondary[ $k ] = \IPS\Member\Group::load( $v );
                }

                return \IPS\Theme::i()->getTemplate( 'members', 'core', 'admin' )->groupCell(
                    \IPS\Member\Group::load( $row['member_group_id'] ), $secondary
                );
            },
            'ip_address'       => function ( $val, $row ) {
                if ( \IPS\Member::loggedIn()->hasAcpRestriction( 'core', 'members', 'membertools_ip' ) )
                {
                    return "<a href='" . \IPS\Http\Url::internal( "app=core&module=members&controller=ip&ip={$val}" ) .
                        "'>{$val}</a>";
                }

                return $val;
            },
            'member_last_post' => function ( $val, $row ) {
                return ( $val )
                    ? \IPS\DateTime::ts( $val )->localeDate()
                    : \IPS\Member::loggedIn()
                                 ->language()
                                 ->addToStack( 'never' );
            },
            'last_visit'       => function ( $val, $row ) {
                return ( $val )
                    ? \IPS\DateTime::ts( $val )->localeDate()
                    : \IPS\Member::loggedIn()
                                 ->language()
                                 ->addToStack( 'never' );
            },
            'name'             => function ( $val, $row ) {
                $member = \IPS\Member::constructFromData( $row );

                if ( $banned = $member->isBanned() )
                {
                    if ( $banned instanceof \IPS\DateTime )
                    {
                        $title = \IPS\Member::loggedIn()->language()->addToStack(
                            'suspended_until', FALSE, [ 'sprintf' => [ $banned->localeDate() ] ]
                        );
                    }
                    else
                    {
                        $title = \IPS\Member::loggedIn()->language()->addToStack( 'banned' );
                    }

                    return "<a href='" .
                        \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) .
                        $row['member_id'] . "'>" . htmlentities( $val, ENT_DISALLOWED, 'UTF-8', FALSE ) .
                        "</a> &nbsp; <span class='ipsBadge ipsBadge_negative'>" . $title . "</span> ";
                }
                else
                {
                    return "<a href='" .
                        \IPS\Http\Url::internal( 'app=core&module=members&controller=members&do=edit&id=' ) .
                        $row['member_id'] . "'>" . htmlentities( $val, ENT_DISALLOWED, 'UTF-8', FALSE ) . "</a>";
                }

            }
        ];

        /* Specify the buttons */
        $table->rowButtons = function ( $row ) {
            $member = \IPS\Member::constructFromData( $row );

            $return = [];

            $return['view'] = array(
                'icon'		=> 'search',
                'title'		=> 'view',
                'link' => \IPS\Http\Url::internal(
                    "app=core&module=members&controller=members&do=view&id={$member->member_id}"
                ),
            );

            if ( isset( $row['vid'] ) and $row['vid'] and
                \IPS\Member::loggedIn()->hasAcpRestriction( 'core', 'members', 'membertools_validating' ) )
            {
                $return['approve'] = [
                    'icon'  => 'check-circle',
                    'title' => 'approve',
                    'link'  => \IPS\Http\Url::internal(
                        "app=core&module=members&controller=members&do=approve&id={$member->member_id}"
                    )->csrf(),
                    'id'    => "{$member->member_id}-approve",
                    'data'  => [
                        'bubble' => '',
                    ]
                ];
                $return['ban'] = [
                    'icon'  => 'times',
                    'title' => 'ban',
                    'link'  => \IPS\Http\Url::internal(
                        "app=core&module=members&controller=members&do=ban&id={$member->member_id}&permban=1"
                    )->csrf(),
                    'id'    => "{$member->member_id}-ban",
                    'data'  => [
                        'bubble' => '',
                    ]
                ];

                if ( !$row['user_verified'] )
                {
                    $return['resend_email'] = [
                        'icon'  => 'envelope-o',
                        'title' => 'resend_validation_email',
                        'link'  => \IPS\Http\Url::internal(
                                'app=core&module=members&controller=members&do=resendEmail&id='
                            ) . $member->member_id,
                        'data'  => [ 'doajax' => '' ],
                        'id'    => "{$member->member_id}-resend",
                    ];
                }
            }

            if ( \IPS\Member::loggedIn()->hasAcpRestriction( 'core', 'members', 'membertools_locked' ) and
                ( \IPS\Settings::i()->ipb_bruteforce_attempts and
                    $row['failed_login_count'] >= (int) \IPS\Settings::i()->ipb_bruteforce_attempts or
                    \IPS\Settings::i()->security_questions_tries and
                    $row['failed_mfa_attempts'] >= (int) \IPS\Settings::i()->security_questions_tries ) )
            {
                $return['unlock'] = [
                    'icon'  => 'unlock',
                    'title' => 'unlock',
                    'link'  => \IPS\Http\Url::internal(
                        "app=core&module=members&controller=members&do=unlock&id={$member->member_id}"
                    )->csrf(),
                    'data'  => [ 'bubble' => '' ]
                ];
            }

            if ( \IPS\Member::loggedIn()->hasAcpRestriction( 'core', 'members', 'member_edit' ) and
                ( \IPS\Member::loggedIn()->hasAcpRestriction( 'core', 'members', 'member_edit_admin' ) or
                    !$member->isAdmin() ) )
            {
                $return['edit'] = [
                    'icon'   => 'pencil',
                    'title'  => 'edit',
                    'link'   => \IPS\Http\Url::internal(
                        "app=core&module=members&controller=members&do=edit&id={$member->member_id}"
                    ),
                    'hotkey' => 'e'
                ];

                if ( $member->member_id != \IPS\Member::loggedIn()->member_id )
                {
                    $return['flag'] = [
                        'icon'   => 'flag',
                        'title'  => 'spam_flag',
                        'link'   => \IPS\Http\Url::internal(
                            "app=core&module=members&controller=members&do=spam&id={$member->member_id}&status=1"
                        )->csrf(),
                        'hidden' => $member->members_bitoptions['bw_is_spammer'],
                        'id'     => "{$member->member_id}-flag",
                        'data'   => [
                            'confirm' => '',
                        ]
                    ];
                    $return['unflag'] = [
                        'icon'   => 'flag ipsType_spammer',
                        'title'  => 'spam_unflag',
                        'link'   => \IPS\Http\Url::internal(
                            "app=core&module=members&controller=members&do=spam&id={$member->member_id}&status=0"
                        )->csrf(),
                        'hidden' => !$member->members_bitoptions['bw_is_spammer'],
                        'id'     => "{$member->member_id}-unflag",
                        'data'   => [
                            'confirm' => '',
                        ]
                    ];
                }
            }

            if ( \IPS\Member::loggedIn()->hasAcpRestriction( 'core', 'members', 'member_delete' ) and
                ( \IPS\Member::loggedIn()->hasAcpRestriction( 'core', 'members', 'member_delete_admin' ) or
                    !$member->isAdmin() ) and $member->member_id != \IPS\Member::loggedIn()->member_id )
            {
                $return['delete'] = [
                    'icon'  => 'times-circle',
                    'title' => 'delete',
                    'link'  => \IPS\Http\Url::internal(
                        "app=core&module=members&controller=members&do=delete&id={$member->member_id}"
                    )->csrf(),
                    'data'  => [
                        'delete'         => '',
                        'delete-message' => \IPS\Member::loggedIn()->language()->addToStack(
                            'member_delete_message', FALSE,
                            [ 'sprintf' => [ htmlentities( $member->name, ENT_DISALLOWED, 'UTF-8', FALSE ) ] ]
                        ),
                        'delete-warning' => \IPS\Member::loggedIn()->language()->addToStack(
                            'member_delete_confirm_desc'
                        ),
                        'noajax'         => ''
                    ]
                ];
            }

            return $return;
        };

        /* Display */
        \IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'indisposable_members_header' );
        \IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'global', 'core' )->block( 'title', (string) $table );
    }

    /**
     * Reindex existing members and find out who is using a disposable e-mail address
     */
    public function reindex()
    {
        \IPS\Session::i()->csrfCheck();
        \IPS\Task::queue( 'indisposable', 'Queue' );

        $backTo = \IPS\Http\Url::internal( 'app=indisposable&module=indisposable&controller=members' );
        \IPS\Output::i()->redirect( $backTo, 'indisposable_queue_started' );
    }

}