<?php


namespace IPS\indisposable\modules\admin\indisposable;

/* To prevent PHP errors (extending class does not exist) revealing path */

use IPS\Helpers\Form\Radio;
use IPS\Helpers\Form\Select;
use IPS\Helpers\Form\YesNo;

if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
    header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
    exit;
}

/**
 * settings
 */
class _settings extends \IPS\Dispatcher\Controller
{
    /**
     * Execute
     *
     * @return	void
     */
    public function execute()
    {
        \IPS\Dispatcher::i()->checkAcpPermission( 'settings_manage' );
        parent::execute();
    }

    /**
     * ...
     *
     * @return	void
     */
    protected function manage()
    {
        $form = new \IPS\Helpers\Form;

        $options = [
            'options'	=> [
                'block'     => 'indisposable_action_block',
                'log'       => 'indisposable_action_log',
            ],
            'toggles' => [
                'block'     => [ 'form_indisposable_member_action_block' ],
                'log'       => [ 'form_indisposable_member_action_log' ]
            ]
        ];

        /**
         * Disposable e-mails
         */
        $form->addHeader( 'indisposable_disposable' );

        // Block or just log registrations with disposable e-mails?
        $form->add(
            new Select( 'indisposable_action', \IPS\Settings::i()->indisposable_action, TRUE, $options )
        );

        // Should we force existing members with disposable e-mails to change?
        $form->add(
            new Radio(
                'indisposable_member_action_ifBlock', \IPS\Settings::i()->indisposable_member_action, FALSE, [
                    'options' => [
                        'none'   => 'indisposable_member_action_none',
                        'prompt' => 'indisposable_member_action_prompt',
                        'force'  => 'indisposable_member_action_force'
                    ]
                ], NULL, NULL, NULL, 'form_indisposable_member_action_block'
            )
        );

        // If our action above is just to log, we don't want the "force change" option to be visible. Allowing a
        // registration to then just say "lol jk" is rather silly.
        $form->add(
            new Radio(
                'indisposable_member_action_ifLog', \IPS\Settings::i()->indisposable_member_action, FALSE, [
                'options' => [
                    'none'   => 'indisposable_member_action_none',
                    'prompt' => 'indisposable_member_action_prompt',
                ]
            ], NULL, NULL, NULL, 'form_indisposable_member_action_log'
            )
        );

        /**
         * GMail Aliases
         */
        $form->addHeader( 'indisposable_aliases' );
        $form->add( new YesNo( 'indisposable_blockAliases', \IPS\Settings::i()->indisposable_blockAliases ) );

        if ( $values = $form->values( TRUE ) )
        {
            if ( $values['indisposable_action'] === 'block' )
            {
                $values['indisposable_member_action'] = $values['indisposable_member_action_ifBlock'] ?? 'none';
            }
            elseif ( $values['indisposable_action'] === 'log' )
            {
                $values['indisposable_member_action'] = $values['indisposable_member_action_ifLog'] ?? 'none';
            }

            unset( $values['indisposable_member_action_ifBlock'], $values['indisposable_member_action_ifLog'] );

            $form->saveAsSettings( $values );
        }

        \IPS\Output::i()->title     = \IPS\Member::loggedIn()->language()->addToStack('settings');
        \IPS\Output::i()->output    = $form;
    }

    // Create new methods with the same name as the 'do' parameter which should execute it
}