<?php

namespace IPS\indisposable;


class _Logger extends \IPS\Patterns\ActiveRecord
{
    /**
     * @brief	[ActiveRecord] Database table
     */
    public static $databaseTable	= 'indisposable_logs';

    /**
     * Log a disposable e-mail use
     *
     * @param string $email
     * @param string $type   The type of the request, e.g. registration, email_change, ...
     * @param null   $member
     * @return bool|null     Returns FALSE if logging is disabled
     */
    public static function log( $email, $type, $member = NULL )
    {
        if ( !\IPS\Settings::i()->indisposable_logs_enabled )
        {
            return FALSE;
        }

        $member = $member ?: \IPS\Member::loggedIn();

        \IPS\Db::i()->insert( static::$databaseTable, [
            'email'     => $email,
            'uagent'    => $_SERVER['HTTP_USER_AGENT'],
            'ip'        => \IPS\Request::i()->ipAddress(),
            'type'      => $type,
            'member_id' => $member->member_id,
            'timestamp' => time()
        ] );
    }

    /**
     * Enable logging
     */
    public static function enable()
    {
        \IPS\Settings::i()->changeValues( [ 'indisposable_logs_enabled' => 1 ] );
    }

    /**
     * Disable logging
     */
    public static function disable()
    {
        \IPS\Settings::i()->changeValues( [ 'indisposable_logs_enabled' => 0 ] );
    }

    /**
     * Prune the log entries
     *
     * @param null $days
     */
    public static function prune( $days=NULL )
    {
        if ( \is_null( $days ) )
        {
            \IPS\Db::i()->delete( static::$databaseTable );
            return;
        }

        $time = time() - ( $days * 86400 );
        \IPS\Db::i()->delete( static::$databaseTable, [ 'timestamp<=?', $time ] );
    }
}